@@ -8,6 +8,8 @@ except ImportError:
 import logging
 import math
 
+from datetime import datetime
+
 from django.conf import settings
 from django.db import models
 from django.db.models import Count
@@ -107,8 +109,8 @@ class MessageBase(Model):
 class GroupedMessage(MessageBase):
     status          = models.PositiveIntegerField(default=0, choices=STATUS_LEVELS, db_index=True)
     times_seen      = models.PositiveIntegerField(default=1, db_index=True)
-    last_seen       = models.DateTimeField(auto_now=True, db_index=True)
-    first_seen      = models.DateTimeField(auto_now_add=True, db_index=True)
+    last_seen       = models.DateTimeField(default=datetime.now, db_index=True)
+    first_seen      = models.DateTimeField(default=datetime.now, db_index=True)
 
     score           = models.IntegerField(default=0)
     
@@ -207,7 +209,7 @@ class GroupedMessage(MessageBase):
 class Message(MessageBase):
     message_id      = models.CharField(max_length=32, null=True, unique=True)
     group           = models.ForeignKey(GroupedMessage, blank=True, null=True, related_name="message_set")
-    datetime        = models.DateTimeField(auto_now_add=True, db_index=True)
+    datetime        = models.DateTimeField(default=datetime.now, db_index=True)
     url             = models.URLField(verify_exists=False, null=True, blank=True)
     server_name     = models.CharField(max_length=128, db_index=True)
     site            = models.CharField(max_length=128, db_index=True, null=True)
