@@ -7,12 +7,11 @@ from django.shortcuts import render_to_response
 from django.utils import simplejson
 from django.utils.safestring import mark_safe
 
-from sentry.helpers import urlread
 from sentry.models import GroupedMessage
 from sentry.plugins import GroupActionProvider
+from sentry.plugins.sentry_redmine import conf
 
-import conf
-
+import base64
 import urllib
 import urllib2
 
@@ -50,16 +49,34 @@ class CreateRedmineIssue(GroupActionProvider):
                 }), headers={
                     'Content-type': 'application/json',
                 })
+
+                if conf.REDMINE_USERNAME and conf.REDMINE_PASSWORD:
+                    authstring = base64.encodestring('%s:%s' % (conf.REDMINE_USERNAME, conf.REDMINE_PASSWORD))[:-1]
+                    req.add_header("Authorization", "Basic %s" % authstring)
+                
                 try:
                     response = urllib2.urlopen(req, data).read()
                 except urllib2.HTTPError, e:
-                    raise Exception('%s: %s' % (e.code, e.read()))
-                
-                data = simplejson.loads(response)
-                RedmineIssue.objects.create(group=group, issue_id=data['id'])
-                group.data['redmine'] = {'issue_id': data['id']}
-                group.save()
-                return HttpResponseRedirect(reverse('sentry-group', args=[group.pk]))
+                    if e.code == 422:
+                        data = simplejson.loads(e.read())
+                        form.errors['__all__'] = 'Missing or invalid data'
+                        for message in data:
+                            for k, v in message.iteritems():
+                                if k in form.fields:
+                                    form.errors.setdefault(k, []).append(v)
+                                else:
+                                    form.errors['__all__'] += '; %s: %s' % (k, v)
+                    else:
+                        form.errors['__all__'] = 'Bad response from Redmine: %s %s' % (e.code, e.msg)
+                except urllib2.URLError, e:
+                    print dir(e), e.__dict__
+                    form.errors['__all__'] = 'Unable to reach Redmine host: %s' % (e.reason,)
+                else:
+                    data = simplejson.loads(response)
+                    RedmineIssue.objects.create(group=group, issue_id=data['id'])
+                    group.data['redmine'] = {'issue_id': data['id']}
+                    group.save()
+                    return HttpResponseRedirect(reverse('sentry-group', args=[group.pk]))
         else:
             description = 'Sentry Message: %s' % request.build_absolute_uri(group.get_absolute_url())
             description += '\n\n<pre>' + (group.traceback or group.message) + '</pre>'
@@ -68,6 +85,8 @@ class CreateRedmineIssue(GroupActionProvider):
                 'subject': group.error(),
                 'description': description,
             })
+            
+        global_errors = form.errors.get('__all__')
 
         BASE_TEMPLATE = "sentry/group/details.html"
 
