@@ -10,6 +10,11 @@ from django.conf import settings
 if not settings.configured:
     settings.configure(
         DATABASE_ENGINE='sqlite3',
+        DATABASES={
+            'default': {
+                'ENGINE': 'sqlite3',
+            },
+        },
         # HACK: this fixes our threaded runserver remote tests
         # DATABASE_NAME='test_sentry',
         # TEST_DATABASE_NAME='test_sentry',
