@@ -5,10 +5,12 @@ try:
     import cPickle as pickle
 except ImportError:
     import pickle
+import datetime
 import getpass
 import logging
 import os.path
 import sys
+import time
 import threading
 import warnings
 
@@ -22,10 +24,11 @@ from django.core.signals import got_request_exception
 from django.core.servers import basehttp
 from django.test import TestCase
 from django.template import TemplateSyntaxError
+from django.utils import simplejson
 from django.utils.encoding import smart_unicode
 
 from sentry import conf
-from sentry.helpers import transform
+from sentry.helpers import transform, get_signature, get_auth_header
 from sentry.models import Message, GroupedMessage
 from sentry.client.base import SentryClient
 from sentry.client.handlers import SentryHandler
@@ -851,7 +854,7 @@ class SentryViewsTest(TestCase):
     def testGroup(self):
         self.client.login(username='admin', password='admin')
         resp = self.client.get(reverse('sentry-group', args=[2]), follow=True)
-        self.assertEquals(resp.status_code, 200)
+        self.assertEquals(resp.status_code, 200, resp.content)
         self.assertTemplateUsed(resp, 'sentry/group/details.html')
 
 class RemoteSentryTest(TestCase):
@@ -883,15 +886,13 @@ class RemoteSentryTest(TestCase):
 
     def testNoKey(self):
         resp = self.client.post(reverse('sentry-store'))
-        self.assertEquals(resp.status_code, 403)
-        self.assertEquals(resp.content, 'Invalid credentials')
+        self.assertEquals(resp.status_code, 400)
 
     def testNoData(self):
         resp = self.client.post(reverse('sentry-store'), {
             'key': conf.KEY,
         })
-        self.assertEquals(resp.status_code, 403)
-        self.assertEquals(resp.content, 'Missing data')
+        self.assertEquals(resp.status_code, 400)
 
     def testBadData(self):
         resp = self.client.post(reverse('sentry-store'), {
@@ -920,13 +921,28 @@ class RemoteSentryTest(TestCase):
             'data': base64.b64encode(pickle.dumps(transform(kwargs)).encode('zlib')),
             'key': conf.KEY,
         })
-        self.assertEquals(resp.status_code, 200)
+        self.assertEquals(resp.status_code, 200, resp.content)
         instance = Message.objects.get()
         self.assertEquals(instance.message, 'hello')
         self.assertEquals(instance.server_name, 'not_dcramer.local')
         self.assertEquals(instance.level, 40)
         self.assertEquals(instance.site, 'not_a_real_site')
 
+    def testTimestamp(self):
+        timestamp = datetime.datetime.now() - datetime.timedelta(hours=1)
+        kwargs = {u'message': 'hello', 'timestamp': timestamp.strftime('%s.%f')}
+        resp = self.client.post(reverse('sentry-store'), {
+            'data': base64.b64encode(pickle.dumps(transform(kwargs)).encode('zlib')),
+            'key': conf.KEY,
+        })
+        self.assertEquals(resp.status_code, 200, resp.content)
+        instance = Message.objects.get()
+        self.assertEquals(instance.message, 'hello')
+        self.assertEquals(instance.datetime, timestamp)
+        group = instance.group
+        self.assertEquals(group.first_seen, timestamp)
+        self.assertEquals(group.last_seen, timestamp)
+
     def testUngzippedData(self):
         kwargs = {'message': 'hello', 'server_name': 'not_dcramer.local', 'level': 40, 'site': 'not_a_real_site'}
         resp = self.client.post(reverse('sentry-store'), {
@@ -940,6 +956,7 @@ class RemoteSentryTest(TestCase):
         self.assertEquals(instance.site, 'not_a_real_site')
         self.assertEquals(instance.level, 40)
 
+
     def testByteSequence(self):
         """
         invalid byte sequence for encoding "UTF8": 0xedb7af
@@ -961,6 +978,20 @@ class RemoteSentryTest(TestCase):
         self.assertEquals(instance.level, 40)
         self.assertTrue(instance.data['__sentry__']['exc'])
 
+    def testSignature(self):
+        kwargs = {'message': 'hello', 'server_name': 'not_dcramer.local', 'level': 40, 'site': 'not_a_real_site'}
+        ts = time.time()
+        message = base64.b64encode(simplejson.dumps(transform(kwargs)))
+        sig = get_signature(message, ts)
+
+        resp = self.client.post(reverse('sentry-store'), message, content_type='application/octet-stream', AUTHORIZATION=get_auth_header(sig, ts, 'foo'))
+        self.assertEquals(resp.status_code, 200, resp.content)
+        instance = Message.objects.get()
+        self.assertEquals(instance.message, 'hello')
+        self.assertEquals(instance.server_name, 'not_dcramer.local')
+        self.assertEquals(instance.site, 'not_a_real_site')
+        self.assertEquals(instance.level, 40)
+
     # def testFunctionException(self):
     #     try: raise Exception(lambda:'foo')
     #     except: get_client().create_from_exception()
